package POD2::LT;

use 5.005;
use strict;
use warnings;

require Exporter;
our @ISA = qw(Exporter);
our $VERSION = '0.02';

1;
__END__
=encoding iso-8859-13

=head1 NAME

POD2::LT - Lithuanian translation of Perl documentation

=head1 SYNOPSIS

  % perldoc POD2::LT;

=head1 DESCRIPTION

POD2::LT yra lietuviškų Perlo dokumentacijos vertimų rinkinys. Šiuo metu jį sudaro ši dokumentacija:

=over 4

=item *

L<perlintro|POD2::LT::perlintro>

=item *

L<perlreref|POD2::LT::perlreref>

=item *

L<perl582delta|POD2::LT::perl582delta>

=item *

L<perl583delta|POD2::LT::perl583delta>

=item *

L<lwpcook|POD2::LT::lwpcook>

=back

=head1 AUTHOR

POD2::LT kol kas sudaro Petro Kudaro vertimai (pagalba verčiant dokumentaciją
bei taisant klaidas visada laukiama).
POD2::LT paketas išleistas Petro Kudaro <moxliukas@delfi.lt>

=head1 SEE ALSO

L<perl>, L<perldoc>.

=cut

